

% 
% m-file which plays with bandpass noise
%
%  Examines the correlation function
%           the spectral density
%  
%
% Author: M. Fitz
% Last modified: 9/19/01
%
close all 
clear all
fs=22050;
ilength=2048;
time=(0:ilength-1)/fs;
sigma=1.0;
w=sigma*randn(1,ilength);
% 
%Implementing the bandpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=1000;
f_c=6500;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
% Forcing impulse response to have unit energy
%
hr=2*bw*sinc(2*bw*(time2-half))*2.*cos(2*pi*f_c*(time2-half));
%
% filtering
%
nc=conv(w,hr)/fs;
nctrun=nc(length+1:ilength+length);
%
% Plotting filtered output noise
%
%looking at frequency domain
ncfs=fft(nctrun,ilength)/fs;
ncf=fftshift(ncfs);
%
% Computing output PSD
%
psdnctot=ncf.*conj(ncf)/ilength*fs;
psdncdb=10*log10(psdnctot);
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
% 
% Implementing a quadrature demodulator
%
deltaf=750;
ntildei=sqrt(2).*cos(2*pi*(f_c-deltaf)*time).*nctrun;
ntildeq=-sqrt(2).*sin(2*pi*(f_c-deltaf)*time).*nctrun;
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bwlp=4000;
lengthlp=512;
time2=(0:lengthlp)/fs;
halflp=lengthlp/2/fs;
ng=2*bw/fs*1.2;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bwlp*sinc(2*bwlp*(time2-halflp));
%
% filtering
%
ni=conv(ht,ntildei)/fs;
nq=conv(ht,ntildeq)/fs;
%
% Truncating to a length ilength
%
nz=ni(lengthlp+1:ilength+lengthlp)+j*nq(lengthlp+1:ilength+lengthlp);
%looking at frequency domain, N_z(t)
nzfs=fft(nz,ilength)/fs;
nzf=fftshift(nzfs);
%
% Computing output PSD
%
psdnztot=nzf.*conj(nzf)/ilength*fs;
psdnzdb=10*log10(psdnztot);
%looking at frequency domain N_I(t)
nifs=fft(real(nz),ilength)/fs;
nif=fftshift(nifs);
%
% Computing output PSD
%
psdnitot=nif.*conj(nif)/ilength*fs;
psdnidb=10*log10(psdnitot);
%looking at frequency domain N_Q(t)
nqfs=fft(imag(nz),ilength)/fs;
nqf=fftshift(nqfs);
%
% Computing output PSD
%
psdnqtot=nqf.*conj(nqf)/ilength*fs;
psdnqdb=10*log10(psdnqtot);
nccorrtot=xcorr(nctrun,'unbiased');
nicorrtot=xcorr(real(nz),'unbiased');
nqcorrtot=xcorr(imag(nz),'unbiased');
ninqcorrtot=xcorr(real(nz),imag(nz),'unbiased');
figure(1)
subplot(3,3,1), plot(time2-half,nccorrtot(ilength-length/2:ilength+length/2))
title('Average correlation function of N_C(t)')
%xlabel('time, seconds')
axis([-half half -2*ng 2*ng])
subplot(3,3,2), plot(time2-half,nicorrtot(ilength-length/2:ilength+length/2))
title('Average correlation function of N_I(t)')
%xlabel('time, seconds')
axis([-half half -ng ng])
subplot(3,3,3), plot(time2-half,nqcorrtot(ilength-length/2:ilength+length/2))
title('Average correlation function of N_Q(t)')
%xlabel('time, seconds')
axis([-half half -ng ng])
subplot(3,3,8), plot(time2-half,ninqcorrtot(ilength-length/2:ilength+length/2))
title('Average correlation function of N_I(t)N_Q(t)')
%xlabel('time, seconds')
axis([-half half -2*ng 2*ng])
subplot(3,3,4), plot(freq,psdncdb)
title('Average of the measured PSD of N_C(t)')
%xlabel('frequency, Hz')
axis([-fs/2 fs/2 -100 -20])
subplot(3,3,5), plot(freq,psdnidb)
title('Average of the measured PSD of N_I(t)')
%xlabel('frequency, Hz')
axis([-bwlp bwlp -100 -20])
subplot(3,3,6), plot(freq,psdnqdb)
title('Average of the measured PSD of N_Q(t)')
%xlabel('frequency, Hz')
axis([-bwlp bwlp -100 -20])
subplot(3,3,7), plot(freq,psdnzdb)
title('Average of the measured PSD of N_z(t)')
xlabel('frequency, Hz')
axis([-bwlp bwlp -100 -20])
pause
%
% Looking at multiple sample functions of the noise
% to compute some empirical averages
%
for ii=1:4000
w=sigma*randn(1,ilength);
% 
%Implementing the bandpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=1000;
f_c=6500;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
% Forcing impulse response to have unit energy
%
hr=2*bw*sinc(2*bw*(time2-half))*2.*cos(2*pi*f_c*(time2-half));
%
% filtering
%
nc=conv(w,hr)/fs;
nctrun=nc(length+1:ilength+length);
%
% Plotting filtered output noise
%
%looking at frequency domain
ncfs=fft(nctrun,ilength)/fs;
ncf=fftshift(ncfs);
%
% Computing output PSD
%
psdnctot=psdnctot+ncf.*conj(ncf)/ilength*fs;
psdncdb=10*log10(psdnctot/ii);
% 
% Implementing a quadrature demodulator
%
deltaf=750;
ntildei=sqrt(2).*cos(2*pi*(f_c-deltaf)*time).*nctrun;
ntildeq=-sqrt(2).*sin(2*pi*(f_c-deltaf)*time).*nctrun;
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bwlp=4000;
lengthlp=512;
time2=(0:lengthlp)/fs;
halflp=lengthlp/2/fs;
ng=2*bw/fs*1.2;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bwlp*sinc(2*bwlp*(time2-halflp));
%
% filtering
%
ni=conv(ht,ntildei)/fs;
nq=conv(ht,ntildeq)/fs;
%
% Truncating to a length ilength
%
nz=ni(lengthlp+1:ilength+lengthlp)+j*nq(lengthlp+1:ilength+lengthlp);
%looking at frequency domain, N_z(t)
nzfs=fft(nz,ilength)/fs;
nzf=fftshift(nzfs);
%
% Computing output PSD
%
psdnztot=psdnztot+nzf.*conj(nzf)/ilength*fs;
psdnzdb=10*log10(psdnztot/ii);
%looking at frequency domain N_I(t)
nifs=fft(real(nz),ilength)/fs;
nif=fftshift(nifs);
%
% Computing output PSD
%
psdnitot=psdnitot+nif.*conj(nif)/ilength*fs;
psdnidb=10*log10(psdnitot/ii);
%looking at frequency domain N_Q(t)
nqfs=fft(imag(nz),ilength)/fs;
nqf=fftshift(nqfs);
%
% Computing output PSD
%
psdnqtot=+psdnqtot+nqf.*conj(nqf)/ilength*fs;
psdnqdb=10*log10(psdnqtot/ii);
nccorrtot=nccorrtot+xcorr(nctrun,'unbiased');
nicorrtot=nicorrtot+xcorr(real(nz),'unbiased');
nqcorrtot=nqcorrtot+xcorr(imag(nz),'unbiased');
ninqcorrtot=ninqcorrtot+xcorr(real(nz),imag(nz),'unbiased');
 if mod(ii,25)==0
   ii
   figure(1)
   subplot(3,3,1), plot(time2-half,nccorrtot(ilength-length/2:ilength+length/2)/ii)
   title('Average correlation function of N_C(t)')
   %xlabel('time, seconds')
   axis([-half half -2*ng 2*ng])
   subplot(3,3,2), plot(time2-half,nicorrtot(ilength-length/2:ilength+length/2)/ii)
   title('Average correlation function of N_I(t)')
   %xlabel('time, seconds')
   axis([-half half -ng ng])
   subplot(3,3,3), plot(time2-half,nqcorrtot(ilength-length/2:ilength+length/2)/ii)
   title('Average correlation function of N_Q(t)')
   %xlabel('time, seconds')
   axis([-half half -ng ng])
   subplot(3,3,8), plot(time2-half,ninqcorrtot(ilength-length/2:ilength+length/2)/ii)
   title('Average correlation function of N_I(t)N_Q(t)')
   %xlabel('time, seconds')
   axis([-half half -2*ng 2*ng])
   subplot(3,3,4), plot(freq,psdncdb)
   title('Average of the measured PSD of N_C(t)')
   %xlabel('frequency, Hz')
   axis([-fs/2 fs/2 -100 -20])
   subplot(3,3,5), plot(freq,psdnidb)
   title('Average of the measured PSD of N_I(t)')
   %xlabel('frequency, Hz')
   axis([-bwlp bwlp -100 -20])
   subplot(3,3,6), plot(freq,psdnqdb)
   title('Average of the measured PSD of N_Q(t)')
   %xlabel('frequency, Hz')
   axis([-bwlp bwlp -100 -20])
   subplot(3,3,7), plot(freq,psdnzdb)
   title('Average of the measured PSD of N_z(t)')
   xlabel('frequency, Hz')
   axis([-bwlp bwlp -100 -20])
   pause(0.5)
 end 
end
