%  sigs_ex1.m
%  A Matlab program to play with continuous and discrete signals
%  The example signal is a cosine wave
%
%  Author: M. Fitz
%  Last revision: 12/31/99
%
%
%  fs=sample rate
%  numsamp=number of samples
%  
fs=22050;
numsamp=22050;
% 
% time is the vector of the sample times
%
time=(1:numsamp)/fs;
%
% Generating a cosine wave 
% fm=cosine frequency
% 
fm=1024;
x=cos(2*pi*fm*time);
sound(x,fs)
figure(1)
plot(time,x)
h=plot(time,x)
set(h,'linewidth', 2.0);
axis([0 3/fm -1.2 1.2])
xlabel('Time, t','Fontsize',16)
ylabel('x(t)','Fontsize',16)
%
% Calculating power from the time signal
% This is a Riemann sum approximation to (2.5)
% Note: T=numsamp/fs and h=1/fs
%
pxt=sum(x.*x)/numsamp
%
% Looking at frequency domain
%
% fft evaluates the DTFT at a set of equally spaced points 
%  That is (2.28) evaluated at discrete points in frequency
% on [0,1]
xfs=fft(x)/fs;
%
% fftshift moves this to [-0.5, 0.5]
%
xf=fftshift(xfs);
% 
% Computing energy spectrum  (2.47)
%
gxf=xf.*conj(xf);
% 
%  psdx is an approximation to the continuous time PSD
%
psdx=gxf/numsamp*fs;
% 
% Assigning frequencies to the samples of the PSD
%
figure(2)
freq=linspace((-numsamp/2+1)/numsamp*fs,fs/2,numsamp);
plot(freq,psdx)   
h=plot(freq,psdx);
set(h,'linewidth', 2.0);
axis([-10000 10000 0 0.25])
xlabel('Frequency, f','Fontsize',16)
ylabel('X(f)','Fontsize',16)
%
% Calculating power from the PSD
% This is a Riemann sum approximation to the power given in (2.33)
%
pxf=sum(psdx)*fs/numsamp
