% sigsex5.m
% m-file for playing around with a pulse signal
% Examples for signals and systems review 
% Author: M. Fitz
% Last modified: 6/10/06
%
fs=22050;  % sample rate
ilength=1024;  % signal length
z=zeros(1,ilength);
z(1:20)=ones(1,20);  % T_p=907us
% time variable is the sample number times the sample period
time=(0:ilength-1)/fs;
% looking at time waveform
figure(1)  % This is Fig. 2.9a
plot(time,z) 
axis([0 0.01 -0.1 1.1])
xlabel('time, t, seconds','Fontsize',16,'Position', [0.005 -0.17 0])
ylabel('x(t)','Fontsize',16)
sound(z,fs)
% computing the energy of the time waveform
% Using Reimann sum approximation to integral
eztbb=sum(z.*conj(z))/fs;
% computing power in the voice signal
pzt=eztbb/ilength*fs
%looking a frequency domain
zfs=fft(z);
%
% Does Rayleigh energy thoerem work?
%
ezfbb=sum(zfs.*conj(zfs))/ilength/fs; 
zf=fftshift(zfs);
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
%
% Calculating PSD in dB
%
psdz=zf.*conj(zf)/ilength/fs;
psdzdb=10*log10(psdz);
% 
% Power in frequency domain
%
pzf=sum(psdz)*fs/ilength
figure(2)
plot(freq,psdzdb)   % Fig. 2.8 a)
axis([-5000 5000 -90 -40])
xlabel('Frequency, f, Hertz','Fontsize',16,'Position', [-9.09495e-13 -93 0])
ylabel('G_x(f), dB','Fontsize',16,'Position', [-5600 -65 0])
%
% specifying the impulse response of a lowpass filter
%
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number and less than 4096
bw=2500;
hlength=2048;
time2=(0:hlength)/fs;
half=hlength/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
figure(3)
plot(time2,ht)
%title('Low pass filter impulse response for W=2.5KHz')
xlabel('time, seconds','Fontsize',16)
ylabel('h(t)','Fontsize',16)
axis([0.036 0.056 -2000 5000])
%ylabel('h(t)')
%
% computing frequency domain
%
Hf1=fft(ht,8192);
Hf=fftshift(Hf1)/fs;
freq2=(-4096:4095)/8196*fs;
figure(4)
plot(freq2,10*log10(abs(Hf)))
%title('A lowpass filter magnitude transfer function')
xlabel('Frequency, Hz','Fontsize',16)
ylabel('H(f)','Fontsize',16)
%ylabel('|H(f)|, dB')
axis([-5000 5000 -60 10])
% 
% Filtering the voice signal
%
yout=conv(ht,z)/fs;
ylength=size(yout)
time3=(0:ylength(2)-1)/fs;
%
%  Looking at the output time signal
%
figure(5)
plot(time3',yout)
axis([0.042 0.052 -0.1 1.1])
soundsc(z,fs)
%title('Filtered voice saying "Bingo"')
xlabel('Time, t, seconds','Fontsize',16,'Position',[0.047 -0.17 0])

ylabel('y(t)','Fontsize',16)
soundsc(yout,fs)

%looking at frequency domain
youtfs=fft(yout)/fs;
youtf=fftshift(youtfs);
%
% Computing output PSD
%
psdyout=youtf.*conj(youtf)/ylength(2)*fs;
psdyoutdb=10*log10(psdyout);
% frequency variable
freq=(-ylength(2)/2:ylength(2)/2-1)/ylength(2)*fs;
figure(6)
plot(freq,psdyoutdb)
axis([-5000 5000 -90 -40])
xlabel('Frequency, f, Hz','Fontsize',16,'Position', [-9.09495e-13 -93 0])
ylabel('G_y(f)','Fontsize',16, 'Position', [-5600 -65 0])
m=yout;
save message m fs
