

% 
% m-file which implements a double sideband amplitude 
% demodulation algorithm
%
% Coherent detection with carrier phase reference produced by
% open loop filtering of the output of a squaring device
%  
%
% Author: M. Fitz
% Last modified: 1/9/00
%
load dsbam
% dsbam.mat is a file containing variables mess and fs
% xc is the DSB-AM modulated signal
% mess is a filtered computer generated voice saying "bingo"
% mess was generated by truncating m in Chap1Ex2.m
% f_c is the carrier frequency
% fs=sampling rate 22050Hz
% xc has 16384 samples
% mess has 16384 samples
[ilength jlength]=size(mess);
% time variable is the sample number times the sample period
time=(0:16383)/fs;
% 
% Implementing the ideal EE501 channel
% y_c(t)=x_c(t-\tau_p)
% Implement a delay of one symbol (for example)
% Phase offset=-7KHz/22050Hz*(360)=-114
%
sigma=1.0;
yc=transpose([0; xc(1:16383)]);
%yc=transpose([0; xc(1:16383)])+sigma*randn(1,16384);
figure(1)
plot(time,yc)
title('Received DSB-AM signal')
xlabel('time, seconds')
%ylabel('y_c(t)')
% 
% Implementing a quadrature demodulator
% deltaf=the frequency offset between the transmitter and receiver
deltaf=0;
ytildei=sqrt(2).*cos(2*pi*(f_c-deltaf)*time).*yc;
ytildeq=-sqrt(2).*sin(2*pi*(f_c-deltaf)*time).*yc;
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=4000;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
%
% filtering
%
yi=conv(ht,ytildei)/fs;
yq=conv(ht,ytildeq)/fs;
%
% Truncating to a length 16384
%
yz=yi(1:16384)+j*yq(1:16384);
figure(2)
%plot(time,yi(1:16384), time, yq(1:16384))
plot(yi,yq)
title('Vector diagram output for received complex envelope')
xlabel('In-Phase Component')
ylabel('Quadrature Component')
axis([-1 1 -1 1])
%
% Implementing squaring device
% 2*phi_p=-228.6=131.4
%
z=yz.*yz;
figure(3)
plot(z)
title('Vector diagram after squaring device')
xlabel('In-Phase Component')
ylabel('Quadrature Component')
axis([-1 1 -1 1])
%
% Implementing a sliding window accumulator
%  This accumulator smooths out the effects of noise
%  Not needed if noise is absent
% lenref=length of the sliding window
% lenref must be even
%
lenref=30;
href=ones(1,lenref)/sqrt(lenref);
zout=conv(z,href);
figure(4)
plot(zout)
title('Vector diagram after filtering')
xlabel('In-Phase Component')
ylabel('Quadrature Component')
axis([-1 1 -1 1])
%
% Implementing a demodulation delay to
% match the smoothing filter delay
%
demod=[zeros(1,lenref/2) yz].*exp(-j*0.5*angle(zout(1:16384+lenref/2)));
%
% Output vector plot
%
figure(5)
plot(demod)
title('Vector diagram after derotation')
xlabel('In-Phase Component')
ylabel('Quadrature Component')
axis([-1 1 -1 1])
%
% Plot of output demodulated signal
%
figure(6)
mhat=real(demod);
plot(time,mhat(1:16384))
title('Demodulation output')
xlabel('Time, seconds')
ylabel('Output')
soundsc(mess,fs)
%
% Normalizing output signal
%
soundsc(mhat,fs)
