

% 
% m-file for generating a large carrier amplitude modulated (LC-AM) signal
%  
%
% Author: M. Fitz
% Last modified: 01/12/00
%
load message
% message.mat is a file containing variables m and fs
% m is a filtered computer generated voice saying "bingo"
% m was generated in Chap1Ex2.m
% fs=sampling rate 22050Hz
% Truncating mess to a length of 16384
mess=m(1:16384);
[ilength jlength]=size(mess);
% 
% Finding the minimum of the message signal
% This determines how small the modulation index must be
%
m1=min(mess)
% time variable is the sample number times the sample period
time=(0:16383)/fs;
% looking at time waveform
figure(1)
plot(time,mess)
title('Computer generated voice saying "Bingo"')
xlabel('time, seconds')
ylabel('m(t)')
soundsc(mess,fs)
%
% Looking at the frequency domain for the message signal
%
mfs=fft(mess)/fs;
mf=fftshift(mfs);
psdm=mf.*conj(mf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(2)
plot(freq,10*log10(psdm))
axis([-5000 5000 -80 -20])
title('Power spectrum of the filtered voice saying "Bingo"')
xlabel('Frequency, Hertz')
%
%  Large Carrier - Amplitude modulation
%  Note:  W=3KHz (approximately)
%         f_c=7KHz
%         A_c=2 
%  a must be chosen so that am(t)>-1 for all t
%  min(m(t))=-0.89..
a=1;
f_c=4000;
A_c=2;
%
%  Generating the complex envelope
%
xz=A_c*(1+a*mess);
%
%  Generating the bandpass signal
%
xc=sqrt(2)*real(xz.*transpose(exp(j*2*pi*f_c*time)));
figure(3)
%
%  Plotting the time waveform for the bandpass signal
%
plot(time,xc)
title('Large carrier amplitude modulation')
xlabel('time, seconds')
%ylabel('x_c(t)')
% 
%  Zooming in on a smaller time scale to get a better idea of LC-AM
%
figure(4)
plot(time(3600:3800),sqrt(2)*xz(3600:3800),time(3600:3800),xc(3600:3800))
title('Message signal and the modulated signal')
xlabel('time, seconds')
%ylabel('x_c(t)')
%
% Looking at the output LC-AM signal in the frequency domain
%
xcfs=fft(xc)/fs;
xcf=fftshift(xcfs);
psdxc=xcf.*conj(xcf)/ilength*fs;
figure(5)
plot(freq,10*log10(psdxc))
axis([-fs/2 fs/2 -80 -20])
title('Power spectrum of the LC-AM signal')
xlabel('Frequency, Hertz')
%ylabel('G_x_z(f)')
save lcam mess xc f_c fs
