

% 
% m-file for generating a single sideband amplitude modulated signal
%  
%
% Author: M. Fitz
% Last modified: 9/16/00
%
load message
% message.mat is a file containing variables m and fs
% m is a filtered computer generated voice saying "bingo"
% m was generated in Chap1Ex2.m
% fs=sampling rate 22050Hz
% Truncating mess to a length of 16384
%fs=22050;
messin=m;
ilength=16384;
% time variable is the sample number times the sample period
%ilength=16384;
time=(0:ilength-1)/fs;
%
% A sinusoidal test signal
%
%messin=cos(2*pi*1000*time');
% specifying the impulse response of a notch filter at DC
%
% bw=one-sided bandwidth of notch in Hz
% length=impulse response length in samples
% length must be an even number and less than 4096
bw=200;
length=2048;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal notch filter truncated in length
%
% All pass portion
%
ap=zeros(size(time2));
ap(length/2)=fs;
%
% computing the bandpass portion
%
hlp=2*bw*sinc(2*bw*(time2-half));
ht=ap-hlp;
% figure(3)
% plot(time2,hlp)
% title('Notch filter impulse response for W=100Hz')
% xlabel('time, seconds')
% ylabel('h(t)')
%
% computing frequency domain
%
hf1=fft(ht,8192);
hf=fftshift(hf1)/fs;
freq2=(-4096:4095)/8192*fs;
figure(1)
plot(freq2,10*log10(abs(hf)))
title('A notch filter magnitude transfer function')
xlabel('Frequency, Hz')
ylabel('|H(f)|, dB')
axis([-500 500 -60 10])
%
% looking at time waveform
%
% figure(1)
% plot(time,mess)
% title('Computer generated voice saying "Bingo"')
% xlabel('time, seconds')
% ylabel('m(t)')
% soundsc(mess,fs)
%
% Looking at the frequency domain for the message signal
%
mess1=conv(ht,messin)/fs;
mess=mess1(1:16384);
%
% Comparing message without and with notch filtering
%
soundsc(messin,fs)
soundsc(mess,fs)
mfs=fft(mess)/fs;
mf=fftshift(mfs);
psdm=mf.*conj(mf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(2)
plot(freq,10*log10(psdm))
axis([-5000 5000 -80 -20])
title('Energy spectrum of the filtered voice saying "Bingo"')
xlabel('Frequency, Hertz')
%ylabel('G_m(f)')
%
%  Single sideband - Amplitude modulation
%  Note:  W=2.5KHz (approximately)
%         f_c=7KHz
%         A_c=1 
%
%  Generating the complex envelope
%
%  An ideal Hilbert Transformer is
%  h(t)=1/(pi*t)
%  A truncated, causal discrete time filter 
%  The length of the impulse response is length
%  length should be even
%
length=128;
time2=(0:length)/fs;
% 
% Delay is set here to ensure that the phase delay through the filter
%  appears to be produced by an even number of symbols (length/2)
% Make length<=1024
%
% FIR design using a sampled version of the continuous time HT
%
half=(length/2)/fs;
% hqt=1/pi./(time2-half)/fs;
% hqt(length/2+1)=0;
%
%  FIR design using remez
%
hqt=remez(length, [0.03 0.3 0.31 0.99], [1 1 1 1], [100 1], 'Hilbert');
figure(3)
plot(time2,hqt)
title('Hilbert transform impulse response')
xlabel('time, seconds')
ylabel('h_Q(t)')
%
% computing frequency domain
%
Hf1=fft(hqt,2048);
Hf=fftshift(Hf1);
freq2=(-1024:1023)/2048*fs;
figure(4)
plot(freq2,10*log10(abs(Hf)))
title('The Hilbert Transformer magnitude transfer function')
xlabel('Frequency, Hz')
%ylabel('|H(f)|, dB')
axis([-300 300 -10 2])
%
% Note the Hilbert Transformer is implemented with a delay
% The delay will cause a linear phase shift with frequency 
% phase=phase of nondelay signal - (2 pi delay f)
%
delay=(length/2)/fs;
figure(5)
plot(freq2,angle(Hf.*exp(j*2*pi*delay*freq2)))
title('The Hilbert Transformer phase response')
xlabel('Frequency, Hz')
axis([-3000 3000 -2 2])
%ylabel('|H(f)|, dB')
%axis([-300 300 -60 10])
%
% Producing the quadrature signal
%
xq=conv(mess,hqt);
maxq=max(xq);
%
%  Producing the in-phase signal
%  Note a delay must be implemented to get the appropriate phase
%  cancellation
%  Delay=length/2
xi=[zeros(length/2,1); mess];
maxi=max(xi);
%  
%  Generating the complex envelope
%  Truncating to ilength samples
%
ac=1;
xz=ac*(xi(1:ilength)+j*xq(1:ilength));
%
%  Using a transmitted reference (needed for example 6)
%
%xz=ac*(xi(1:ilength)+j*xq(1:ilength))+0.1*ac;
xzfs=fft(xz)/fs;
xzf=fftshift(xzfs);
psdxz=xzf.*conj(xzf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(6)
plot(real(xz(1000:ilength)),imag(xz(1000:ilength)))
title('Vector Diagram of SSB-AM')
xlabel('x_I(t)')
ylabel('x_Q(t)')
%
figure(7)
plot(freq,10*log10(psdxz))
axis([-5000 5000 -80 -20])
title('Power spectrum of the complex envelope')
xlabel('Frequency, Hertz')
%
%  Generating the bandpass signal
%
f_c=7000;
xc1=sqrt(2)*real(xz.*transpose(exp(j*2*pi*f_c*time)));
%
%  Adding a transmitted reference
%
%xc1=0.1*cos(2*pi*f_c*time')+xc;
% 
% No transmitted reference
%
%xc1=xc;
figure(8)
%
%  Plotting the time waveform for the bandpass signal
%
plot(time,xc1)
title('Single sideband amplitude modulation')
xlabel('time, seconds')
%
% Looking at the output SSB-AM signal in the frequency domain
%
figure(9)
xcfs=fft(xc1)/fs;
xcf=fftshift(xcfs);
psdxc=xcf.*conj(xcf)/ilength*fs;
plot(freq,10*log10(psdxc))
axis([-fs/2 fs/2 -80 -20])
title('Power spectrum of the SSB-AM signal')
xlabel('Frequency, Hertz')
save ssbam mess xc1 f_c fs
