% 
% m-file which implements a transmitted reference demodulator 
% for single-side band AM
%  
%
% Author: M. Fitz
% Last modified: 9/16/00
%
load ssbam
% ssbam.mat is a file containing variables mess, xc1, f_c, and fs
% xc1 is the SSB-AM modulated signal
% mess is a filtered computer generated voice saying "bingo"
% mess was generated by truncating m in Chap1Ex2.m
% f_c is the carrier frequency
% fs=sampling rate 22050Hz
% xc1 has 16384 samples
% mess has 16384 samples
[ilength jlength]=size(mess);
% time variable is the sample number times the sample period
time=(0:16383)/fs;
% 
% Implementing the ideal EE501 channel
% y_c(t)=x_c(t-\tau_p)
% Implement a delay of one symbol (for example)
%
sigma=0.1;
%
% A time delay of one symbol
% \phi_p=-7000/22050*2*pi=114 degrees
%
% signal without noise
%
yc=transpose([0; xc1(1:16383)]);
%
% signal with noise
%
%yc=transpose([0; xc1(1:16383)])+sigma*randn(1,16384);
figure(1)
plot(time,yc)
title('Received SSB-AM signal')
xlabel('time, seconds')
%ylabel('y_c(t)')
% 
% Implementing a quadrature demodulator
%
deltaf=0;
ytildei=sqrt(2).*cos(2*pi*(f_c-deltaf)*time).*yc;
ytildeq=-sqrt(2).*sin(2*pi*(f_c-deltaf)*time).*yc;
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=4000;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
%
% filtering
%
yi=conv(ht,ytildei)/fs;
yq=conv(ht,ytildeq)/fs;
%
% Truncating to a length 16384
%
yz=yi(1:16384)+j*yq(1:16384);
yzfs=fft(yz)/fs;
yzf=fftshift(yzfs);
psdyz=yzf.*conj(yzf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(2)
plot(freq,10*log10(psdyz))
axis([-5000 5000 -80 -20])
title('Power spectrum of the complex envelope')
xlabel('Frequency, Hertz')
%
%  Implementing notch filter to get rid of transmitted reference portion
%
%
% specifying the impulse response of a notch filter at DC
%
% bw=one-sided bandwidth of notch in Hz
% length=impulse response length in samples
% length must be an even number and less than 4096
bw=100;
length=2048;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal notch filter truncated in length
%
% All pass portion
%
ap=zeros(size(time2));
ap(length/2)=fs;
%
% computing the bandpass portion
%
hlp=2*bw*sinc(2*bw*(time2-half));
ht=ap-hlp;
%
%  Notch filter frequency response
%
hf1=fft(ht,8192);
hf=fftshift(hf1)/fs;
freq2=(-4096:4095)/8192*fs;
figure(3)
plot(freq2,10*log10(abs(hf)))
title('A notch filter magnitude transfer function')
xlabel('Frequency, Hz')
ylabel('|H(f)|, dB')
axis([-500 500 -60 10])
%
%  Low pass filter frequency response
%
hfls=fft(hlp,8192);
hfl=fftshift(hfls)/fs;
freq2=(-4096:4095)/8192*fs;
dumfig=4;
figure(dumfig)
plot(freq2,10*log10(abs(hfl)))
title('A notch filter magnitude transfer function')
xlabel('Frequency, Hz')
ylabel('|H(f)|, dB')
axis([-500 500 -60 10])
%
% Computing the output of the notched filter
%
y_h=conv(yz,ht)/fs;
yhfs=fft(y_h(1:16384))/fs;
yhf=fftshift(yhfs);
psdyh=yhf.*conj(yhf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
%
% Looking at the output power spectrum
%
dumfig=dumfig+1;
figure(dumfig)
plot(freq,10*log10(psdyh))
axis([-5000 5000 -80 -20])
title('Power spectrum of the high pass signal')
xlabel('Frequency, Hertz')
dumfig=dumfig+1;
figure(dumfig)
timeout=1:18432;
plot(timeout, real(y_h), timeout, imag(y_h))
%
%  Implementing LPF to create the demodulation reference
%
y_l=conv(yz,hlp)/fs;
ylfs=fft(y_l(1:16384))/fs;
ylf=fftshift(ylfs);
psdyl=ylf.*conj(ylf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
dumfig=dumfig+1;
figure(dumfig)
plot(freq,10*log10(psdyl))
axis([-5000 5000 -80 -20])
title('Power spectrum of the low pass signal')
xlabel('Frequency, Hertz')
dumfig=dumfig+1;
figure(dumfig)
plot(timeout/fs, angle(y_l)/2/pi*360)
xlabel('Time, seconds')
ylabel('Phase, degrees')
axis([0 16384/fs -150 -90])
demod=y_h./y_l;
dumfig=dumfig+1;
figure(dumfig)
plot(timeout, real(demod), timeout, imag(demod))
mhat=real(demod);
soundsc(mess,fs)
%
% Normalizing output signal
%
maxmhat=max(mhat)
sound(mhat/maxmhat,fs)
