

% 
% m-file for generating a phase and a frequency modulated signal
%  
%
% Author: M. Fitz
% Last modified: 1/28/00
%
load message
% message.mat is a file containing variables m and fs
% m is a filtered computer generated voice saying "bingo"
% m was generated in Chap1Ex2.m
% fs=sampling rate 22050Hz
% Truncating mess to a length of 16384
mess=m(1:16384);
% time variable is the sample number times the sample period
time=(0:16383)/fs;
[ilength jlength]=size(mess);
%
% looking at time waveform
%
figure(1)
plot(time,mess)
title('Message signal')
xlabel('time, seconds')
ylabel('m(t)')
soundsc(mess,fs)
%
%  Computing the important message parameters for 
%  for angle modulation
%
dmdt=diff(mess)*fs;
maxder=max(abs(dmdt));
maxm=max(abs(mess));
%
% Integral of the message signal
% Trapezoidal integration
%
intmess=(cumsum(mess)-mess(1)/2)/fs;
%
% Looking at the frequency domain for the message signal
%
mfs=fft(mess)/fs;
mf=fftshift(mfs);
psdm=mf.*conj(mf)*fs/ilength;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
figure(2)
plot(freq,10*log10(psdm))
axis([-5000 5000 -80 -20])
title('Power spectrum of the filtered voice saying "Bingo"')
xlabel('Frequency, Hertz')
totpowm=sum(psdm);
cumpowm=2*cumsum(psdm(ilength/2+1:ilength))/totpowm;
figure(3)
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
subplot(2,1,1), plot(freq(ilength/2+1:ilength),cumpowm);
axis([0 10000 0.9 1])
title('Cumulative powerof the message signal')
xlabel('frequency,f, Hz')
%
%
%
%  phase and frequency modulation
%  Note:  W=3KHz (approximately)
%         f_c=5.7KHz
%         A_c=1/sqrt(2)  
%         k_p=1
%         k_f=2pi*200
f_c=3500;
A_c=1/sqrt(2);
k_p=1.6
k_f=2*pi*1000
%
%  Generating the complex envelope
%
% Phase modulation
%
xz=A_c*exp(j*k_p*mess);
%
% Frequency modulation
%
%xz=A_c*exp(j*k_f/fs*intmess);
%
% Looking at frequency domain
%
xzfs=fft(xz)/fs;
xzf=fftshift(xzfs);
%
%  Displaying the peak frequency deviation
%  (PM)
'phase modulation'
'[peak frequency deviation]'
[k_p/2/pi*maxder]
%
%  Displaying the peak frequency deviation
%  (FM)
% 'frequency modulation'
% '[peak frequency deviation]'
% [k_f*maxm/2/pi]
%
% Computing Carson's bandwidth
%
psdxzf=fs/ilength*abs(xzf(ilength/2+1:ilength)).^2;
totpow=2*sum(psdxzf);
cumpow=2*cumsum(psdxzf)/totpow;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
subplot(2,1,2), plot(freq(ilength/2+1:ilength),cumpow);
axis([0 10000 0.9 1])
title('Cumulative power versus frequency')
xlabel('Frequency, Hz')
ylabel('Cumulative normalized power')
%
% Filtering to limit the spectral content before upconverting
% 
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=5500;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
%
% filtering
%
xz1=conv(ht,xz)/fs;
xzout=xz1(1:16384);
figure(4)
plot(time,mess,time,abs(xzout))
%axis([-1 1 -1 1])
%
% Looking at frequency domain
%
xzfs1=fft(xzout)/fs;
xzf1=fftshift(xzfs1);
psdxz1=xzf1.*conj(xzf1)*fs/ilength;
figure(5)
plot(freq,10*log10(psdxz1))
axis([-7000 7000 -80 -20])
title('Power spectrum of the complex envelope')
xlabel('Frequency, Hertz')
%
%  Generating the bandpass signal
%
xc=real(xzout).*cos(2*pi*f_c*time')-imag(xzout).*sin(2*pi*f_c*time');
figure(6)
%
%  Plotting the time waveform for the bandpass signal
%
plot(time,xc)
title('Angle modulation')
xlabel('time, seconds')
%ylabel('x_c(t)')
% 
%  Zooming in on a smaller time scale to get a better idea of angle modulation
%
%  Note the message signal must be delayed  since the xz is passed through a 
%  filter
%   
figure(7)
plot(time(3600:3800),mess(3600-length/2:3800-length/2),time(3600:3800),xc(3600:3800))
title('Message signal and the modulated signal')
xlabel('time, seconds')
%ylabel('x_c(t)')
%
% Looking at the output angle modulated signal in the frequency domain
%
xcfs=fft(xc)/fs;
xcf=fftshift(xcfs);
psdxc=xcf.*conj(xcf)*fs/ilength;
figure(8)
plot(freq,10*log10(psdxc))
axis([-fs/2 fs/2 -80 -20])
title('Power spectrum of the bandpass signal')
xlabel('Frequency, Hertz')
save pm mess xc f_c fs
