% 
% Generating the time waveform of OCDM
% Author: M. Fitz
% Last modified: 8/23/02
% 
close all
clear all
numpts=2048;
K_b=4;
%
% Number of stream OCDM put back to back
%
K_s=50;
T_p=1;
T_h=0.25;
T_t=T_p+T_h;
time=linspace(0,(K_s*T_t), numpts*(K_s*T_t));
timesym=linspace(0,T_p, numpts);
timefs=linspace(0,T_t,numpts*(T_t));
%
% Spreading waveform 1
%
s(1,:)=ones(1,numpts);
%
% Spreading waveform 2
%
s(2,:)=ones(1,numpts);
i2=find(timesym>0.5*T_p);
s(2,i2)=-ones(size(i2));
%
% Spreading waveform 3
%
s(3,:)=ones(1,numpts);
i3a=find(timesym>0.25*T_p&timesym<=0.5*T_p);
s(3,i3a)=-ones(size(i3a));
i3b=find(timesym>0.75*T_p);
s(3,i3b)=-ones(size(i3b));
%
% Spreading waveform 4
%
s(4,:)=ones(1,numpts);
i4a=find(timesym>0.75*T_p);
s(4,i4a)=-ones(size(i4a));
i4b=find(timesym<=0.25*T_p);
s(4,i4b)=-ones(size(i4b));
%
%  An example channel
%
%  Computing the tilde waveforms
%
for ll=1:K_b
	stilde(ll,:)=zeros(1,numpts*(T_p+T_h));
	alpha_1=0.7*exp(j*pi/3);
	%alpha_1=0.7*exp(j*0);
	alpha_0=sqrt(1-abs(alpha_1)^2);
	stilde(ll,1:numpts*T_p)=stilde(ll,1:numpts*T_p)+alpha_0*s(ll,:);
	stilde(ll,T_h*numpts+1:(T_p+T_h)*numpts)=stilde(ll,T_h*numpts+1:(T_p+T_h)*numpts)+alpha_1*s(ll,:);  
end
stilde_a=abs(stilde);
stilde_p=angle(stilde);
figure(1)
plot(timefs, (stilde_a(1,:)),timefs, (stilde_a(4,:)))
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Normalized time, t/T_p','Fontsize',16)
ylabel('x_A(t)','Fontsize',16)
legend('l=1','l=3')
axis([0 1.25 0 2])	
figure(2)
plot(timefs, (stilde_p(1,:)),timefs, (stilde_p(4,:)))
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Normalized time, t/T_p','Fontsize',16)
ylabel('x_P(t)','Fontsize',16)
legend('l=1','l=3')
axis([0 1.25 -3.14 3.14])	
%
%  Computing the received signal
%
r_ztot=zeros(1,numpts*(K_s*T_t));
for mm=1:K_s
    %
	% Waveform 1 is the pilot channel
	%
	%x_z=s(1,:);
	%
	% Waveform 1 is not the pilot channe
	%
	x_z=zeros(1,numpts);
	for ll=1:K_b
    	d_z(ll)=sign(rand(1)-0.5);
		wavekk=d_z(ll)*s(ll,:);
		x_z=x_z+wavekk;
	end
% x_a=abs(x_z);
% figure(1)
% plot(time, x_a)
% hs=subplot(1,1,1);
% set(hs,'Fontsize',14);
% xlabel('Normalized time, t/T_p','Fontsize',16)
% ylabel('x_A(t)','Fontsize',16)
% legend('I=i_1','I=i_2')
% axis([0 1 0 5])	
%
%  Computing the received signal
%
	r_z=zeros(1,numpts*(T_p+T_h));
	alpha_1=0.7*exp(j*pi/3);
	%alpha_1=0.7*exp(j*0);
	alpha_0=sqrt(1-abs(alpha_1)^2);
	r_z(1,1:numpts*T_p)=r_z(1,1:numpts*T_p)+alpha_0*x_z;
	r_z(1,T_h*numpts+1:(T_p+T_h)*numpts)=r_z(1,T_h*numpts+1:(T_p+T_h)*numpts)+alpha_1*x_z;
%
%   Accumulating contribution of all bits
%
	r_ztot(1+(mm-1)*T_t*numpts:((mm-1)*T_t+(T_p+T_h))*numpts)=r_ztot(1+(mm-1)*T_t*numpts:((mm-1)*T_t+(T_p+T_h))*numpts)+r_z;
end
r_a=abs(r_ztot);
figure(3)
plot(time, r_a)
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Normalized time, t/T_p','Fontsize',16)
ylabel('r_A(t)','Fontsize',16)
axis([-0.25 T_p+T_h+0.25 0 5])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Forming the matched filters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(4)
hold on
for k1=1:K_s
	for kk=1:K_b
		qtilde(kk)=sum(r_ztot(1+(k1-1)*T_t*numpts:((k1-1)*T_t+(T_p+T_h))*numpts).*conj(stilde(kk,:)))/numpts;
	end
%	plot(qtilde(1),'ro')
% 	plot(qtilde(2),'bo')
 	plot(qtilde(3),'go')
% 	plot(qtilde(4),'ko')
end
hold off

