% 
% Generating the time waveform of OFDM
% Author: M. Fitz
% Last modified: 2/1/03
% 
close all
clear all
numsym=64;
sam_sym=64;
sam_filt=32;
%
% Channel
%
alpha=0.7*exp(j*pi/3);
tau1=0.25;
%
% We consider numsym OFDM symbols spaced 2*sam_sym apart in time
%
numpts=2*sam_sym*numsym;
K_b=4;
f_d=0.5;
T_p=1;
T_h=0.25;
timesym=linspace(0,T_p*(1-1/sam_sym), sam_sym);
timetot=linspace(0,2*numsym*T_p,numpts+1);
x_z=zeros(1,numpts+1);
for ll=1:numsym
%
%  Use second one for no cyclic prefix
%
	x_zll=zeros(1,sam_sym);
	for kk=1:K_b
    	d_z=sign(rand(1)-0.5);
		tonekk=d_z*exp(j*2*pi*f_d*(2*kk-K_b-1)*timesym);
	 	x_zll=x_zll+tonekk;
	end
	x_z((ll-1)*2*sam_sym+1:(ll-1)*2*sam_sym+sam_sym)=x_z((ll-1)*2*sam_sym+1:(ll-1)*2*sam_sym+sam_sym)+x_zll;
end
y_z=zeros(1,numpts+1+sam_filt);
y_z(1:numpts+1)=y_z(1:numpts+1)+sqrt(1-abs(alpha)^2)*x_z;
y_z(tau1*sam_sym+1:tau1*sam_sym+numpts+1)=y_z(tau1*sam_sym+1:tau1*sam_sym+numpts+1)+alpha*x_z;
figure(1)
plot(timetot(1:2*sam_sym),abs(y_z(1:2*sam_sym)))
xlabel('Normalized Time, t/T_p','Fontsize',14)
ylabel('Y_A(t)','Fontsize',14)
%
%  Looking at subcarrier matched filters
%
carrier_num=[1 2 3 4];
for ii = 1:1:length(carrier_num)
    delta_f=f_d*(2*carrier_num(ii)-K_b-1);
	temp = exp(j*2*pi*delta_f*timesym);
    m_f(ii,:)= exp(-j*2*pi*delta_f*(1-1/sam_sym))*temp;
    mf_output(ii,:) = conv(y_z,m_f(ii,:))/(sam_sym);
end
for ll=1:numsym
	mf_sampled(:,ll)=sqrt(1-abs(alpha)^2)*mf_output(:,2*sam_sym*(ll-1)+sam_sym)+alpha'*mf_output(:,2*sam_sym*(ll-1)+sam_sym*(T_p+T_h));
end
figure(2)
if length(carrier_num) == 1 
    plot(mf_sampled(1,:),'ro')
    title(['Carrier number = ',num2str(carrier_num(1))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
elseif length(carrier_num) == 2
    subplot(211)
    plot(mf_sampled(1,:),'ro')
    title(['Carrier number = ',num2str(carrier_num(1))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(212)
    plot(mf_sampled(2,:),'.')
    title(['Carrier number = ',num2str(carrier_num(2))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
elseif length(carrier_num) == 3
    subplot(221)
    plot(mf_sampled(1,:),'ro')
    title(['Carrier number = ',num2str(carrier_num(1))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(222)
    plot(mf_sampled(2,:),'ro')
    title(['Carrier number = ',num2str(carrier_num(2))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(212)
    plot(mf_sampled(3,:),'.')
    title(['Carrier number = ',num2str(carrier_num(3))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
elseif length(carrier_num) == 4
    subplot(221)
    plot(mf_sampled(1,:),'ro')
    title(['Carrier number = ',num2str(carrier_num(1))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(222)
    plot(mf_sampled(2,:),'ro')
    title(['Carrier number = ',num2str(carrier_num(2))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
    subplot(223)
    plot(mf_sampled(3,:),'ro')
    title(['Carrier number = ',num2str(carrier_num(3))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-2.5 2.5 -2.5 2.5])
    subplot(224)
    plot(mf_sampled(4,:),'ro')
    title(['Carrier number = ',num2str(carrier_num(4))])
	xlabel('Q_I(k)','Fontsize',12)
    ylabel('Q_Q(k)','Fontsize',12)
	axis([-1.5 1.5 -1.5 1.5])
end
