

% 
% m-file which plays with the filtering of noise
% moment, densities, sample paths
%
%  
%
% Author: M. Fitz
% Last modified: 3/19/01
%
clear all
close all
fs=22050;
ilength=2048;
time=(0:ilength-1)/fs;
sigma=1.0;
%
% Viewing one sample function of the noise
%
w=sigma*randn(1,ilength);
w1000(1)=w(1000);
soundsc(w)
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=1600;
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
%
% filtering
%
nout=conv(w,ht)/fs;
n=nout(length+1:ilength+length);
n1000=n(1000);
soundsc(nout)
figure(1)
wtot=w;
w2tot=w.*w;
ntot=n;
n2tot=n.*n;
figure(1)
subplot(4,2,1), plot(time,wtot)
title('Average value of the input noise')
%xlabel('time, seconds')
axis([0 0.05 -2 2])
subplot(4,2,2), plot(time,ntot)
title('Average value of the filtered noise')
%xlabel('time, seconds')
axis([0 0.05 -1 1])
subplot(4,2,3), plot(time,w2tot)
title('Average value of the square of the input noise')
xlabel('time, seconds')
axis([0 0.05 0 4])
subplot(4,2,4), plot(time,n2tot)
title('Average value of the square of the filtered noise')
xlabel('time, seconds')
axis([0 0.05 0 1])
subplot(4,2,5), hist(w1000,50)
subplot(4,2,6), hist(n1000,50)
subplot(4,2,7), plot(time2+half,w(length:length+length))
axis([half 3*half -3 3])
title('Input noise')
xlabel('time, seconds')
subplot(4,2,8), plot(time2+half,n(length:length+length))
axis([half 3*half -2 2])
title('Filtered noise')
xlabel('time, seconds')
pause
%
% Looking at multiple sample functions of the noise
% to compute some empirical averages
%
for ii=1:4000
 w=sigma*randn(1,ilength);
 w1000(ii+1)=w(1000);
 wtot=w+wtot;
 w2tot=w.*w+w2tot;
% 
% Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
%
% filtering
%
 nout=conv(w,ht)/fs;
 n=nout(length+1:ilength+length);
 n1000(ii+1)=n(1000);
 ntot=n+ntot;
 n2tot=n.*n+n2tot;
 if (ii==100*floor(ii/100)) 
   ii
   figure(1)
   subplot(4,2,1), plot(time,wtot/(ii+1))
   title('Average value of the input noise')
   %xlabel('time, seconds')
   axis([0 0.05 -2 2])
   subplot(4,2,2), plot(time,ntot/(ii+1))
   title('Average value of the filtered noise')
   %xlabel('time, seconds')
   axis([0 0.05 -1 1])
   subplot(4,2,3), plot(time,w2tot/(ii+1))
   title('Average value of the square of the input noise')
   xlabel('time, seconds')
   axis([0 0.05 0 4])
   subplot(4,2,4), plot(time,n2tot/(ii+1))
   title('Average value of the square of the filtered noise')
   xlabel('time, seconds')
   axis([0 0.05 0 1])
   subplot(4,2,5), hist(w1000,50)
   subplot(4,2,6), hist(n1000,50)
   subplot(4,2,7), plot(time2+half,w(length:length+length))
   axis([half 3*half -3 3])
   title('Input noise')
   xlabel('time, seconds')
   subplot(4,2,8), plot(time2+half,n(length:length+length))
   axis([half 3*half -2 2])
   title('Filtered noise')
   xlabel('time, seconds')
   pause(1.0)
 end 
end
