

% 
% m-file which plays with noise
%
%  Correlation functions
%  Spectral density
%  Sample density functions
%
%  
%
% Author: M. Fitz
% Last modified: 3/19/01
%
clear all
close all
fs=22050;
ilength=2048;
time=(0:ilength-1)/fs;
sigma=1.0;
%
% Viewing one sample function of the noise
%
w=sigma*randn(1,ilength);
w1000(1)=w(1000);
soundsc(w)
%
%looking at frequency domain
%
wfs=fft(w)/fs;
wf=fftshift(wfs);
%
% Computing output PSD
%
psdwtot=wf.*conj(wf)/ilength*fs;
% frequency variable
freq=(-ilength/2:ilength/2-1)/ilength*fs;
% 
%Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
bw=100;
ng=2*bw/fs*1.2
length=512;
time2=(0:length)/fs;
half=length/2/fs;
%
% impulse response of an ideal bandpass filter truncated length
%
ht=2*bw*sinc(2*bw*(time2-half));
%
% filtering
%
nout=conv(w,ht)/fs;
n=nout(length+1:ilength+length);
n1000=n(1000);
soundsc(nout)
%
%looking at frequency domain
%
nfs=fft(n)/fs;
nf=fftshift(nfs);
%
% Computing output PSD
%
psdntot=nf.*conj(nf)/ilength*fs;
figure(1)
wcorrtot=xcorr(w,'unbiased');
ncorrtot=xcorr(n,'unbiased');
subplot(4,2,1), plot(time2-half,wcorrtot(ilength-length/2:ilength+length/2))
title('Average correlation function of the input noise')
%xlabel('time, seconds')
axis([-half half -1.2 1.2])
subplot(4,2,2), plot(time2-half,ncorrtot(ilength-length/2:ilength+length/2))
title('Average correlation function of the filtered noise')
%xlabel('time, seconds')
axis([-half half -ng ng])
subplot(4,2,3), plot(freq,10*log10(psdwtot))
title('Average value of the measured power spectrum input noise')
xlabel('frequency, Hz')
axis([-fs/2 fs/2 -100 -20])
subplot(4,2,4), plot(freq,10*log10(psdntot))
title('Average value of the measured power spectrum of the filtered noise')
xlabel('frequency, Hz')
axis([-fs/2 fs/2 -100 -20])
subplot(4,2,5), hist(w1000,50)
subplot(4,2,6), hist(n1000,50)
subplot(4,2,7), plot(time2+2*half,w(length:length+length))
axis([2*half 4*half -2 2])
subplot(4,2,8), plot(time2+2*half,n(length:length+length))
axis([2*half 4*half -1 1])
pause
%
% Looking at multiple sample functions of the noise
% to compute some empirical averages
%
for ii=1:4000
 w=sigma*randn(1,ilength);
 wcorr=xcorr(w,'unbiased');
 w1000(ii+1)=w(1000);
 wcorrtot=wcorrtot+wcorr;
%
%looking at frequency domain
%
wfs=fft(w)/fs;
wf=fftshift(wfs);
%
% Computing output PSD
%
psdwtot=wf.*conj(wf)/ilength*fs+psdwtot;
% 
% Implementing the lowpass filters
% 
% bw=one-sided bandwidth in Hz
% length=impulse response length in samples
% length must be an even number
%
% filtering
%
 nout=conv(w,ht)/fs;
 n=nout(length+1:ilength+length);
 ncorr=xcorr(n,'unbiased');
 n1000(ii+1)=n(1000);
 ncorrtot=ncorrtot+ncorr;
%
%looking at frequency domain
%
 nfs=fft(n)/fs;
 nf=fftshift(nfs);
%
% Computing output PSD
%
 psdntot=nf.*conj(nf)/ilength*fs+psdntot;
 if mod(ii,25)==0
   ii
   figure(1)
   subplot(4,2,1), plot(time2-half,wcorrtot(ilength-length/2:ilength+length/2)/(ii+1))
   title('Average correlation function of the input noise')
   %xlabel('time, seconds')
   axis([-half half -1.2 1.2])
   subplot(4,2,2), plot(time2-half,ncorrtot(ilength-length/2:ilength+length/2)/(ii+1))
   title('Average correlation function of the filtered noise')
   %xlabel('time, seconds')
   axis([-half half -ng ng])
   subplot(4,2,3), plot(freq,10*log10(psdwtot/(ii+1)))
   title('Average value of the measured power spectrum input noise')
   xlabel('time, seconds')
   axis([-fs/2 fs/2 -100 -20])
   subplot(4,2,4), plot(freq,10*log10(psdntot/(ii+1)))
   title('Average value of the measured power spectrum of the filtered noise')
   xlabel('time, seconds')
   axis([-fs/2 fs/2 -100 -20])
   subplot(4,2,5), hist(w1000,50)
   subplot(4,2,6), hist(n1000,50)
   subplot(4,2,7), plot(time2+2*half,w(length:length+length))
   axis([2*half 4*half -2 2])
   subplot(4,2,8), plot(time2+2*half,n(length:length+length))
   axis([2*half 4*half -1 1])
   pause(0.5)
 end 
end
