%
%  Program to generate a linear modulation with
%    i) Phase offset
%    ii) frequency 
%
%
%  Author: M. Fitz
%  Last Modified: 1/16/02
% 
clear all
close all
figdum=0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Important parameters for the program
%
%  Number of symbols per burst
%  L_p=preamble length
numburst=18;
%
%  Number of samples per symbol
%
numsam=16;
%
%  Number of symbols of shaping
%
T_u=12;
%
%  Excess bandwidth factor
%
alpha=0.3;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Getting all the timing right
%
%  Time for the whole packet
%
timedata=linspace(1,numburst,numburst)';
%
%  Time for the pulse shape
%
numpts=numsam*T_u+1;
timep=linspace(0,T_u,numpts)+5*eps;
time2=T_u/2;
%
% Symbol time normalized time for transmitter
%
timet=linspace(0,numburst+T_u-1,numsam*(numburst+T_u-1)+1)';
%
% Symbol time normalized time for receiver
%
timer=linspace(0,numburst+2*T_u-1,numsam*(numburst+2*T_u-1)+1)';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Generating the pulse shape for the digital modulation
%
u1=(1-alpha)./(1-(4*alpha*(timep-time2)).^2).*sin(pi*(1-alpha)*(timep-time2))./(pi*(1-alpha)*(timep-time2));
u2=4/pi*alpha./(1-(4*alpha*(timep-time2)).^2).*cos(pi*(1+alpha)*(timep-time2));
ut=(u1+u2);
u=ut/sqrt(sum(ut.*conj(ut))/numsam);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  The Modulator
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Dotting pattern
%  
d=[1 -1 1 -1 1 -1 1 -1 1 -1 1 -1 1 -1 1 -1 1 -1];
dt=zeros(numsam*(numburst-1)+1,1);
dt(numsam*(timedata-1)+1)=d;
%
%  Generating the transmitted signal
%
xz=conv(dt,u);
%
% Making bandpass signals
%
[l1 l2]=size(xz);
time=[1:20*l1];
x_c=real(kron(xz',ones(1,20)).*exp(j*2*pi*time/10));
figdum=figdum+1;
figure(figdum)
plot(time,x_c)
%axis([2500 5000 -2 2])
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Plotting transmitted signal
%
figdum=figdum+1;
figure(figdum)
plot(timet,real(xz))
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Normalized time, t/T','Fontsize',16)
ylabel('x_{I}(t)','Fontsize',16)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Spectrum
%
[numsamp dumi]=size(xz);
xzfs=fft(xz)/numsam;
%
% fftshift moves this to [-0.5, 0.5]
%
xzf=fftshift(xzfs);
% 
% Computing energy spectrum
%
gxzf=xzf.*conj(xzf);
% 
%  psdx is an approximation to the continuous time PSD
%
psdxz=gxzf/numsamp*numsam;
% 
% Assigning frequencies to the samples of the PSD
%
freq=linspace((-numsamp/2+1)/numsamp*numsam,numsam/2,numsamp);
figdum=figdum+1;
figure(figdum)
plot(freq,10*log10(psdxz))
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Normalized frequency, fT','Fontsize',16)
ylabel('G_{x_z}(f)','Fontsize',16)
axis([-8 8 -70 10])
%%%%%%%%%%%%%%%%%%
% Computing the energy
%
E_u=sum(psdxz)
%
% Computing the MS bandwidth
B_u_sq=sum(freq.*freq.*psdxz')/E_u
%
% Computing the CRLB
%
EhopN0dB=linspace(0,20,11);
EhopN0=10.^(EhopN0dB/10);
CRLB=1/8/pi/pi/B_u_sq./EhopN0;
figdum=figdum+1;
figure(figdum)
plot(EhopN0dB,CRLB)
%
%
%  No noise or distortion added
%
y_z=xz;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  The matched filter to the pulse shape
%
q=conv(y_z,u)/sum(u.*u);
figdum=figdum+1;
figure(figdum)
plot(timer,real(q),timer,imag(q))
goofy=[timedata]-1+T_u;
hold on
for i=1:numburst
plot([goofy(i) goofy(i)],[-2,2],'--')
end
plot([1 numsamp],[1 1],'--')
plot([1 numsamp],[-1 -1],'--')
axis([1 20 -2 2])
hold off
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Normalized time, t/T','Fontsize',16)
ylabel('Q(t)','Fontsize',16)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generating scatter plot
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figdum=figdum+1;
figure(figdum)
plot(q(goofy*numsam+1),'bx')
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Q_{I}(k)','Fontsize',16)
ylabel('Q_{Q}(k)','Fontsize',16)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generating vector plot
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figdum=figdum+1;
figure(figdum)
plot(q)
hold on
plot(q(goofy*numsam+1),'ro')
hold off
hs=subplot(1,1,1);
set(hs,'Fontsize',14);
xlabel('Q_{I}(k)','Fontsize',16)
ylabel('Q_{Q}(k)','Fontsize',16)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Generating Eye Diagram
%
figdum=figdum+1;
figure(figdum)
timeye=linspace(-0.5,0.5,numsam+1);
hold on
for kk=1:numburst
	plot(timeye,real(q(((kk-1)+T_u)*numsam-numsam/2+1:((kk-1)+T_u)*numsam+numsam/2+1)))
end
%plot([0 0],[1 -1],'ro')
hold off
