%  Chap1Ex1.m
%  A Matlab program to play with continuous and discrete signals
%  The example signal is a cosine wave
%
%  Author: M. Fitz
%  Last revision: 12/31/99
%
%
%  fs=sample rate
%  numsamp=number of samples
%  
fs=22050;
numsamp=22050;
% 
% time is the vector of the sample times
%
time=(1:numsamp)/fs;
%
% Generating a cosine wave 
% fm=cosine frequency
% 
fm=1;
xi=12*cos(6*pi*fm*time)+3*cos(10*pi*fm*time);
xq=2*sin(6*pi*fm*time)+3*sin(10*pi*fm*time);
xz=xi+j*xq;
xp=angle(xz);
xa=abs(xz);
figure(1)
plot(time,xp)
%
% Calculating power from the time signal
% This is a Riemann sum approximation to (1.37)
% Note: T=numsamp/fs and h=1/fs
%
pxt=sum(x.*x)/numsamp
%
% Looking at frequency domain
%
% fft evaluates the DTFT at a set of equally spaced points
% on [0,1]
xfs=fft(x)/fs;
%
% fftshift moves this to [-0.5, 0.5]
%
xf=fftshift(xfs);
% 
% Computing energy spectrum
%
gxf=xf.*conj(xf);
% 
%  psdx is an approximation to the continuous time PSD
%
psdx=gxf/numsamp*fs;
% 
% Assigning frequencies to the samples of the PSD
%
figure(2)
freq=linspace((-numsamp/2+1)/numsamp*fs,fs/2,numsamp);
plot(freq,psdx)
h=plot(freq,psdx);
set(h,'linewidth', 2.0);
%
% Calculating power from the PSD
% This is a Riemann sum approximation to the power given in (1.40)
%
pxf=sum(psdx)*fs/numsamp
